@@ -145,9 +145,15 @@ void load_dataset(FL_OBJECT *ob, long user_data)
 	}
 	if(dubious == TRUE)
 	{
+	#ifdef XFORMS86
+		choice = fl_show_choice("Hmmm. The File being loaded Seems Strange",
+					"I doubt it's in .lda format","Should I try to Continue?",
+               				3,"Yes","No","Cancel",2);
+	#else
 		choice = fl_show_choice("Hmmm. The File being loaded Seems Strange",
 					"I doubt it's in .lda format","Should I try to Continue?",
                				3,"Yes","No","Cancel");
+	#endif
 		if(choice == 2 || choice == 3)
 		{
 			strcpy(data_matrix_description,"");
@@ -329,9 +335,15 @@ void append_dataset(FL_OBJECT *ob, long user_data)
 	}
 	if(dubious == TRUE)
 	{
+	#ifdef XFORMS86
+		choice = fl_show_choice("Hmmm. The File being Appended Seems Strange",
+					"I doubt it's in .lda format","Should I try to Continue?",
+               				3,"Yes","No","Cancel",2);
+	#else
 		choice = fl_show_choice("Hmmm. The File being Appended Seems Strange",
 					"I doubt it's in .lda format","Should I try to Continue?",
                				3,"Yes","No","Cancel");
+	#endif
 		if(choice == 2 || choice == 3)
 		{
 			strcpy(data_matrix_description,"");
@@ -872,9 +884,13 @@ void import_dataset(FL_OBJECT *ob, long user_data)
 		say_status("Ready");
 		return;
 	}
-
+	#ifdef XFORMS86
+	choice = fl_show_choice("ASCII data is in which format?","","",
+               		3,"Columns","Rows","Cancel",1);
+	#else
 	choice = fl_show_choice("ASCII data is in which format?","","",
                		3,"Columns","Rows","Cancel");
+	#endif
 	if(choice == 3)
 	{
 		reenable_input();
