@@ -59,8 +59,13 @@ void gen_write_variable()
 	}
 	if(check_variable_name(string_one) == FALSE)
 	{
+		#ifdef XFORMS86
+		choice = fl_show_choice("Variable Name already Exists","Overwrite exisiting values?",
+					"",3,"Yes","No","Cancel",2);
+		#else
 		choice = fl_show_choice("Variable Name already Exists","Overwrite exisiting values?",
 					"",3,"Yes","No","Cancel");
+		#endif
 		if(choice == 1)
 		{
 			for(i = 0; i < numb_variables; i++)
@@ -136,8 +141,13 @@ void done_gen(FL_OBJECT *obj, long arg)
 		}
 		if(check_variable_name(string_one) == FALSE)
 		{
+			#ifdef XFORMS86
+			choice = fl_show_choice("Variable Name already Exists","Overwrite exisiting values?",
+						"",3,"Yes","No","Cancel",2);
+			#else
 			choice = fl_show_choice("Variable Name already Exists","Overwrite exisiting values?",
 						"",3,"Yes","No","Cancel");
+			#endif
 			if(choice == 1)
 			{
 				for(i = 0; i < numb_variables; i++)
@@ -197,10 +207,15 @@ int click_done_gen(FL_FORM *form, void *arg)
 	int choice;
 	if(gen_exists == TRUE)
 	{
+		#ifdef XFORMS86
+		choice = fl_show_choice("Exit generate/replace (Data not saved!)?",
+						"","", 3,
+						"Yes","No","Cancel",2);
+		#else
 		choice = fl_show_choice("Exit generate/replace (Data not saved!)?",
 						"","", 3,
 						"Yes","No","Cancel");
-	
+		#endif
 		if(choice == 1)
 		{
 			say_status("Ready");
@@ -340,10 +355,15 @@ void handle_gen_buttons(FL_OBJECT *obj, long arg)
 	{
 		if(gen_exists == TRUE)
 		{
+			#ifdef XFORMS86
+			choice = fl_show_choice("Exit generate/replace (Data not saved!)?",
+							"","", 3,
+							"Yes","No","Cancel",2);
+			#else
 			choice = fl_show_choice("Exit generate/replace (Data not saved!)?",
 							"","", 3,
 							"Yes","No","Cancel");
-	
+			#endif
 			if(choice == 1)
 			{
 				window_geometry[XLDLAS_GENERATE][0] = obj->form->x;
