@@ -792,7 +792,7 @@ void opening_quote()
 		case 40: fl_show_message("\"It is better to be roughly right than precisely wrong.\"",
 					  "",
 					  "- Keynes"); break;
-		case 41: fl_show_message("\"If all else fails, immortality can always be assures by",
+		case 41: fl_show_message("\"If all else fails, immortality can always be assured by",
 					  "spectacular error\"",
 					  "- Galbraith"); break;
 	}
@@ -950,9 +950,15 @@ void handle_cloptions(int numb_arguments, char *arguments[])
 					}
 					if(dubious == TRUE)
 					{
+					#ifdef XFORMS86
+						choice = fl_show_choice("Hmmm. The File being loaded Seems Strange",
+									"I doubt it's in .lda format","Should I try to Continue?",
+        				       				3,"Yes","No","Cancel",2);
+					#else
 						choice = fl_show_choice("Hmmm. The File being loaded Seems Strange",
 									"I doubt it's in .lda format","Should I try to Continue?",
         				       				3,"Yes","No","Cancel");
+        				#endif
 						if(choice == 2 || choice == 3)
 						{
 							strcpy(data_matrix_description,"");
